@@ -3,10 +3,12 @@ from os.path import isdir
 from pathlib import Path
 
 from graphviz import Digraph
+
+from pythautomata.abstract.pdfa_model_exporting_strategy import PDFAModelExportingStrategy
 from pythautomata.automata.wheighted_automaton_definition.weighted_automaton import WeightedAutomaton
 
 
-class WFAImageExporter:
+class WFAImageExporter(PDFAModelExportingStrategy):
 
     def export(self, model: WeightedAutomaton, path=None):
         graph = Digraph('weighted_automaton', format='png')
@@ -34,12 +36,3 @@ class WFAImageExporter:
                 graph.edge(s_from, s_to, str(transitions[key]))
 
         graph.render(self.get_path_for(path, model), cleanup=True)
-
-    def get_path_for(self, path: str, model: WeightedAutomaton):
-        if path is None:
-            name = model.name
-            path = "output_models/" + \
-                   ("" if name is None else f"{name}")
-        if not isdir(path):
-            makedirs(path)
-        return Path(path, model.name)
